aboutsummaryrefslogtreecommitdiff
path: root/mesonbuild/linkers/linkers.py
diff options
context:
space:
mode:
authorKarol Herbst <git@karolherbst.de>2023-05-11 00:09:16 +0200
committerDylan Baker <dylan@pnwbakers.com>2023-06-08 09:49:29 -0700
commit8284be8139925475c358c07be62a082c0984ccbf (patch)
tree13d4c68b627f4c2d0be1cb6a33ef1995e99c0fae /mesonbuild/linkers/linkers.py
parentf02e26877de7a38fce672db9709666ed85706d43 (diff)
downloadmeson-8284be8139925475c358c07be62a082c0984ccbf.zip
meson-8284be8139925475c358c07be62a082c0984ccbf.tar.gz
meson-8284be8139925475c358c07be62a082c0984ccbf.tar.bz2
dependencies/llvm: strip default include dirs
Fixes an issue with rust.bindgen if a cmake LLVM dependency with the system include_type is getting used as a dependency.
Diffstat (limited to 'mesonbuild/linkers/linkers.py')
-rw-r--r--mesonbuild/linkers/linkers.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/mesonbuild/linkers/linkers.py b/mesonbuild/linkers/linkers.py
index 2db82e3..21e0eeb 100644
--- a/mesonbuild/linkers/linkers.py
+++ b/mesonbuild/linkers/linkers.py
@@ -1487,9 +1487,9 @@ class AIXDynamicLinker(PosixDynamicLinkerMixin, DynamicLinker):
all_paths.add(os.path.join(build_dir, p))
# We should consider allowing the $LIBPATH environment variable
# to override sys_path.
- sys_path = env.get_compiler_system_dirs(self.for_machine)
+ sys_path = env.get_compiler_system_lib_dirs(self.for_machine)
if len(sys_path) == 0:
# get_compiler_system_dirs doesn't support our compiler.
# Use the default system library path
all_paths.update(['/usr/lib', '/lib'])
else:
@@ -1487,9 +1487,9 @@ class AIXDynamicLinker(PosixDynamicLinkerMixin, DynamicLinker):
if len(sys_path) == 0:
- # get_compiler_system_dirs doesn't support our compiler.
+ # get_compiler_system_lib_dirs doesn't support our compiler.
# Use the default system library path
all_paths.update(['/usr/lib', '/lib'])